@@ -12,6 +12,12 @@
 #define __NR_fadvise64		1234
 #endif
 
+#ifndef __NR_sys_splice
+#define __NR_sys_splice		1297
+#define __NR_sys_tee		1301
+#define __NR_sys_vmsplice	1302
+#endif
+
 #define nop	asm volatile ("hint @pause" ::: "memory");
 
 #define ia64_popcnt(x)							\
