@@ -45,7 +45,7 @@ int groupid = 0;
 int thread_number = 0;
 int shm_id = 0;
 int temp_stall_ts;
-char *fio_inst_prefix = _INST_PREFIX;
+const char *fio_inst_prefix = _INST_PREFIX;
 
 static volatile int startup_sem;
 
@@ -439,7 +439,7 @@ static void do_io(struct thread_data *td)
 		rate_throttle(td, usec, icd.bytes_done[td->ddir], td->ddir);
 
 		if (check_min_rate(td, &e)) {
-			if (rate_quit)
+			if (exitall_on_terminate)
 				terminate_threads(td->groupid);
 			td_verror(td, ENOMEM);
 			break;
