@@ -348,7 +348,6 @@ struct thread_data {
 #define td_verror(td, err)	__td_verror((td), (err), strerror((err)))
 #define td_vmsg(td, err, msg)	__td_verror((td), (err), (msg))
 
-extern int rate_quit;
 extern int exitall_on_terminate;
 extern int thread_number;
 extern int shm_id;
@@ -356,7 +355,7 @@ extern int groupid;
 extern int terse_output;
 extern FILE *f_out;
 extern FILE *f_err;
-extern char *fio_inst_prefix;
+extern const char *fio_inst_prefix;
 extern int temp_stall_ts;
 
 extern struct thread_data *threads;
