@@ -409,7 +409,7 @@ static struct option long_options[FIO_JOB_OPTS + FIO_CMD_OPTS] = {
 
 static int def_timeout = DEF_TIMEOUT;
 
-static char fio_version_string[] = "fio 1.8";
+static char fio_version_string[] = "fio 1.9";
 
 static char **ini_file;
 static int max_jobs = MAX_JOBS;
@@ -417,7 +417,6 @@ static int max_jobs = MAX_JOBS;
 struct thread_data def_thread;
 struct thread_data *threads = NULL;
 
-int rate_quit = 0;
 int exitall_on_terminate = 0;
 int terse_output = 0;
 unsigned long long mlock_size = 0;
@@ -517,7 +516,7 @@ static void fixup_options(struct thread_data *td)
 static char *to_kmg(unsigned int val)
 {
 	char *buf = malloc(32);
-	char post[] = { 0, 'K', 'G', 'P', -1 };
+	char post[] = { 0, 'K', 'M', 'G', 'P', -1 };
 	char *p = post;
 
 	while (*p != -1) {
@@ -539,8 +538,8 @@ static char *to_kmg(unsigned int val)
  */
 static int add_job(struct thread_data *td, const char *jobname, int job_add_num)
 {
-	char *ddir_str[] = { "read", "write", "randread", "randwrite",
-			     "rw", NULL, "randrw" };
+	const char *ddir_str[] = { "read", "write", "randread", "randwrite",
+				   "rw", NULL, "randrw" };
 	struct stat sb;
 	int numjobs, ddir, i;
 	struct fio_file *f;
