@@ -93,7 +93,7 @@ static int init_iolog_read(struct thread_data *td)
 	FILE *f;
 	int rw, reads, writes;
 
-	f = fopen(td->iolog_file, "r");
+	f = fopen(td->read_iolog_file, "r");
 	if (!f) {
 		perror("fopen read iolog");
 		return 1;
@@ -125,9 +125,9 @@ static int init_iolog_read(struct thread_data *td)
 		INIT_LIST_HEAD(&ipo->list);
 		ipo->offset = offset;
 		ipo->len = bytes;
-		if (bytes > td->max_bs)
-			td->max_bs = bytes;
 		ipo->ddir = rw;
+		if (bytes > td->max_bs[rw])
+			td->max_bs[rw] = bytes;
 		list_add_tail(&ipo->list, &td->io_log_list);
 	}
 
@@ -151,9 +151,9 @@ static int init_iolog_read(struct thread_data *td)
  */
 static int init_iolog_write(struct thread_data *td)
 {
-	FILE *f = fopen(td->iolog_file, "w");
+	FILE *f;
 
-	f = fopen(td->iolog_file, "w");
+	f = fopen(td->write_iolog_file, "w+");
 	if (!f) {
 		perror("fopen write iolog");
 		return 1;
@@ -172,13 +172,14 @@ int init_iolog(struct thread_data *td)
 {
 	int ret = 0;
 
-	if (td->read_iolog)
+	if (td->io_ops->flags & FIO_CPUIO)
+		return 0;
+
+	if (td->read_iolog_file)
 		ret = init_iolog_read(td);
-	else if (td->write_iolog)
+	else if (td->write_iolog_file)
 		ret = init_iolog_write(td);
 
-	free(td->iolog_file);
-	td->iolog_file = NULL;
 	return 0;
 }
 
@@ -194,7 +195,7 @@ int setup_rate(struct thread_data *td)
 		return -1;
 	}
 
-	nr_reads_per_sec = (td->rate * 1024) / td->min_bs;
+	nr_reads_per_sec = (td->rate * 1024) / td->min_bs[DDIR_READ];
 	td->rate_usec_cycle = 1000000 / nr_reads_per_sec;
 	td->rate_pending_usleep = 0;
 	return 0;
