@@ -5,6 +5,7 @@
 #include <sys/uio.h>
 #include <sys/syscall.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <linux/unistd.h>
 
 #define FIO_HAVE_LIBAIO
@@ -39,27 +40,11 @@ static inline int ioprio_set(int which, int who, int ioprio)
 	return syscall(__NR_ioprio_set, which, who, ioprio);
 }
 
-static _syscall6(int, sys_splice, int, fdin, loff_t *, off_in, int, fdout, loff_t *, off_out, size_t, len, unsigned int, flags);
-static _syscall4(int, sys_vmsplice, int, fd, const struct iovec *, iov, unsigned long, nr_segs, unsigned int, flags);
-static _syscall4(int, sys_tee, int, fdin, int, fdout, size_t, len, unsigned int, flags);
-
-static inline int splice(int fdin, loff_t *off_in, int fdout, loff_t *off_out,
-			 size_t len, unsigned long flags)
-{
-	return sys_splice(fdin, off_in, fdout, off_out, len, flags);
-}
-
-static inline int tee(int fdin, int fdout, size_t len, unsigned int flags)
-{
-	return sys_tee(fdin, fdout, len, flags);
-}
-
-static inline int vmsplice(int fd, const struct iovec *iov,
-			   unsigned long nr_segs, unsigned int flags)
-{
-	return sys_vmsplice(fd, iov, nr_segs, flags);
-}
-
+/*
+ * Just check for SPLICE_F_MOVE, if that isn't there, assume the others
+ * aren't either.
+ */
+#ifndef SPLICE_F_MOVE
 #define SPLICE_F_MOVE	(0x01)	/* move pages instead of copying */
 #define SPLICE_F_NONBLOCK (0x02) /* don't block on the pipe splicing (but */
 				 /* we may still block on the fd we splice */
@@ -67,6 +52,24 @@ static inline int vmsplice(int fd, const struct iovec *iov,
 #define SPLICE_F_MORE	(0x04)	/* expect more data */
 #define SPLICE_F_GIFT   (0x08)  /* pages passed in are a gift */
 
+static inline int splice(int fdin, loff_t *off_in, int fdout, loff_t *off_out,
+			 size_t len, unsigned long flags)
+{
+	return syscall(__NR_sys_splice, fdin, off_in, fdout, off_out, len, flags);
+}
+
+static inline int tee(int fdin, int fdout, size_t len, unsigned int flags)
+{
+	return syscall(__NR_sys_tee, fdin, fdout, len, flags);
+}
+
+static inline int vmsplice(int fd, const struct iovec *iov,
+			   unsigned long nr_segs, unsigned int flags)
+{
+	return syscall(__NR_sys_vmsplice, fd, iov, nr_segs, flags);
+}
+#endif
+
 #define SPLICE_DEF_SIZE	(64*1024)
 
 enum {
@@ -81,6 +84,18 @@ enum {
 #define BLKGETSIZE64	_IOR(0x12,114,size_t)
 #endif
 
+#ifndef BLKFLSBUF
+#define BLKFLSBUF	_IO(0x12,97)
+#endif
+
+static inline int blockdev_invalidate_cache(int fd)
+{
+	if (!ioctl(fd, BLKFLSBUF))
+		return 0;
+
+	return errno;
+}
+
 static inline int blockdev_size(int fd, unsigned long long *bytes)
 {
 	if (!ioctl(fd, BLKGETSIZE64, bytes))
